@@ -32,40 +32,27 @@ class KCMKScreen : public KQuickAddons::ConfigModule
 {
     Q_OBJECT
 
-    Q_PROPERTY(OutputModel *outputModel READ outputModel
-               NOTIFY outputModelChanged)
-    Q_PROPERTY(bool backendReady READ backendReady
-               NOTIFY backendReadyChanged)
-    Q_PROPERTY(bool screenNormalized READ screenNormalized
-               NOTIFY screenNormalizedChanged)
-    Q_PROPERTY(bool perOutputScaling READ perOutputScaling
-               NOTIFY perOutputScalingChanged)
-    Q_PROPERTY(bool primaryOutputSupported READ primaryOutputSupported
-               NOTIFY primaryOutputSupportedChanged)
-    Q_PROPERTY(bool outputReplicationSupported READ outputReplicationSupported
-               NOTIFY outputReplicationSupportedChanged)
-    Q_PROPERTY(qreal globalScale READ globalScale WRITE setGlobalScale
-               NOTIFY globalScaleChanged)
-    Q_PROPERTY(int outputRetention READ outputRetention WRITE setOutputRetention
-               NOTIFY outputRetentionChanged)
-    Q_PROPERTY(bool autoRotationSupported READ autoRotationSupported
-               NOTIFY autoRotationSupportedChanged)
-    Q_PROPERTY(bool orientationSensorAvailable READ orientationSensorAvailable
-               NOTIFY orientationSensorAvailableChanged)
-    Q_PROPERTY(bool tabletModeAvailable READ tabletModeAvailable
-               NOTIFY tabletModeAvailableChanged)
-
+    Q_PROPERTY(OutputModel *outputModel READ outputModel NOTIFY outputModelChanged)
+    Q_PROPERTY(bool backendReady READ backendReady NOTIFY backendReadyChanged)
+    Q_PROPERTY(bool screenNormalized READ screenNormalized NOTIFY screenNormalizedChanged)
+    Q_PROPERTY(bool perOutputScaling READ perOutputScaling NOTIFY perOutputScalingChanged)
+    Q_PROPERTY(bool primaryOutputSupported READ primaryOutputSupported NOTIFY primaryOutputSupportedChanged)
+    Q_PROPERTY(bool outputReplicationSupported READ outputReplicationSupported NOTIFY outputReplicationSupportedChanged)
+    Q_PROPERTY(qreal globalScale READ globalScale WRITE setGlobalScale NOTIFY globalScaleChanged)
+    Q_PROPERTY(int outputRetention READ outputRetention WRITE setOutputRetention NOTIFY outputRetentionChanged)
+    Q_PROPERTY(bool autoRotationSupported READ autoRotationSupported NOTIFY autoRotationSupportedChanged)
+    Q_PROPERTY(bool orientationSensorAvailable READ orientationSensorAvailable NOTIFY orientationSensorAvailableChanged)
+    Q_PROPERTY(bool tabletModeAvailable READ tabletModeAvailable NOTIFY tabletModeAvailableChanged)
 
 public:
-    explicit KCMKScreen (QObject *parent = nullptr,
-                         const QVariantList &args = QVariantList());
+    explicit KCMKScreen(QObject *parent = nullptr, const QVariantList &args = QVariantList());
     ~KCMKScreen() override = default;
 
     void load() override;
     void save() override;
     void defaults() override;
 
-    OutputModel* outputModel() const;
+    OutputModel *outputModel() const;
 
     Q_INVOKABLE void identifyOutputs();
 
